@@ -190,6 +190,7 @@ typedef struct _GSource GSource;
 struct _GSource { uint8_t _data[52]; };
 typedef struct _GSourceCallbackFuncs GSourceCallbackFuncs;
 struct _GSourceCallbackFuncs { uint8_t _data[12]; };
+typedef void* GSourceDisposeFunc;
 typedef void* GSourceDummyMarshal;
 typedef void* GSourceFunc;
 typedef struct _GSourceFuncs GSourceFuncs;
@@ -569,6 +570,7 @@ extern GValueArray* g_value_array_remove(GValueArray*, uint32_t);
 extern GValueArray* g_value_array_sort_with_data(GValueArray*, GCompareDataFunc, void*);
 extern void* g_boxed_copy(GType, void*);
 extern void g_boxed_free(GType, void*);
+extern void g_clear_signal_handler(uint32_t*, GObject*);
 extern void g_enum_complete_type_info(GType, GTypeInfo*, GEnumValue*);
 extern GEnumValue* g_enum_get_value(GEnumClass*, int32_t);
 extern GEnumValue* g_enum_get_value_by_name(GEnumClass*, char*);
